# Generated by ariadne-codegen
# Source: queries.gql

from typing import Any, Dict, Optional, Union

from .async_base_client import AsyncBaseClient
from .base_model import UNSET, UnsetType
from .collection_collections import CollectionCollections
from .collection_create import CollectionCreate
from .collection_document import CollectionDocument
from .collection_document_delete import CollectionDocumentDelete
from .collection_document_set import CollectionDocumentSet
from .collection_document_tag_add import CollectionDocumentTagAdd
from .collection_document_tag_delete import CollectionDocumentTagDelete
from .collection_documents import CollectionDocuments
from .collection_file import CollectionFile
from .collection_file_create import CollectionFileCreate
from .collection_file_delete import CollectionFileDelete
from .collection_file_tag_add import CollectionFileTagAdd
from .collection_file_tag_delete import CollectionFileTagDelete
from .collection_files import CollectionFiles
from .input_types import TagInput


def gql(q: str) -> str:
    return q


class Client(AsyncBaseClient):
    async def collection_create(
        self,
        organization_id: str,
        key: str,
        parent_id: Union[Optional[str], UnsetType] = UNSET,
        **kwargs: Any
    ) -> CollectionCreate:
        query = gql(
            """
            mutation CollectionCreate($organizationID: ID!, $key: ID!, $parentID: ID) {
              collectionCreate(
                organizationID: $organizationID
                key: $key
                parentID: $parentID
              ) {
                __typename
                ... on Collection {
                  ...CollectionReference
                }
                ... on CollectionNotFound {
                  ...CollectionNotFound
                }
              }
            }

            fragment CollectionNotFound on CollectionNotFound {
              id
            }

            fragment CollectionReference on Collection {
              id
              key
            }
            """
        )
        variables: Dict[str, object] = {
            "organizationID": organization_id,
            "key": key,
            "parentID": parent_id,
        }
        response = await self.execute(
            query=query,
            operation_name="CollectionCreate",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionCreate.model_validate(data)

    async def collection_collections(
        self,
        collection_id: str,
        after: Union[Optional[str], UnsetType] = UNSET,
        first: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> CollectionCollections:
        query = gql(
            """
            query CollectionCollections($collectionID: ID!, $after: ID, $first: Int) {
              collection(id: $collectionID) {
                __typename
                ... on Collection {
                  id
                  key
                  collections(after: $after, first: $first) {
                    edges {
                      node {
                        ... on Collection {
                          ...CollectionReference
                        }
                      }
                    }
                    pageInfo {
                      hasNextPage
                      endCursor
                    }
                  }
                }
              }
            }

            fragment CollectionReference on Collection {
              id
              key
            }
            """
        )
        variables: Dict[str, object] = {
            "collectionID": collection_id,
            "after": after,
            "first": first,
        }
        response = await self.execute(
            query=query,
            operation_name="CollectionCollections",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionCollections.model_validate(data)

    async def collection_document(
        self, collection_id: str, doc_key: str, **kwargs: Any
    ) -> CollectionDocument:
        query = gql(
            """
            query CollectionDocument($collectionID: ID!, $docKey: ID!) {
              collection(id: $collectionID) {
                __typename
                ... on Collection {
                  document(key: $docKey) {
                    __typename
                    ... on CollectionDocument {
                      ...CollectionDocumentReference
                    }
                  }
                }
              }
            }

            fragment CollectionDocumentReference on CollectionDocument {
              id
              key
              data
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "collectionID": collection_id,
            "docKey": doc_key,
        }
        response = await self.execute(
            query=query,
            operation_name="CollectionDocument",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionDocument.model_validate(data)

    async def collection_document_set(
        self, collection_id: str, key: str, data: Any, **kwargs: Any
    ) -> CollectionDocumentSet:
        query = gql(
            """
            mutation CollectionDocumentSet($collectionID: ID!, $key: ID!, $data: Base64JSON!) {
              collectionDocumentSet(collectionID: $collectionID, key: $key, data: $data) {
                __typename
                ... on CollectionDocument {
                  ...CollectionDocumentReference
                }
              }
            }

            fragment CollectionDocumentReference on CollectionDocument {
              id
              key
              data
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "collectionID": collection_id,
            "key": key,
            "data": data,
        }
        response = await self.execute(
            query=query,
            operation_name="CollectionDocumentSet",
            variables=variables,
            **kwargs
        )
        _data = self.get_data(response)
        return CollectionDocumentSet.model_validate(_data)

    async def collection_document_delete(
        self, id: str, **kwargs: Any
    ) -> CollectionDocumentDelete:
        query = gql(
            """
            mutation CollectionDocumentDelete($id: ID!) {
              collectionDocumentDelete(id: $id) {
                __typename
                ... on CollectionDocument {
                  ...CollectionDocumentReference
                }
              }
            }

            fragment CollectionDocumentReference on CollectionDocument {
              id
              key
              data
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(
            query=query,
            operation_name="CollectionDocumentDelete",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionDocumentDelete.model_validate(data)

    async def collection_document_tag_add(
        self, id: str, tag: TagInput, **kwargs: Any
    ) -> CollectionDocumentTagAdd:
        query = gql(
            """
            mutation CollectionDocumentTagAdd($id: ID!, $tag: TagInput!) {
              collectionDocumentTagAdd(id: $id, tag: $tag) {
                __typename
                ... on CollectionDocument {
                  ...CollectionDocumentReference
                }
              }
            }

            fragment CollectionDocumentReference on CollectionDocument {
              id
              key
              data
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id, "tag": tag}
        response = await self.execute(
            query=query,
            operation_name="CollectionDocumentTagAdd",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionDocumentTagAdd.model_validate(data)

    async def collection_document_tag_delete(
        self, id: str, tag_key: str, **kwargs: Any
    ) -> CollectionDocumentTagDelete:
        query = gql(
            """
            mutation CollectionDocumentTagDelete($id: ID!, $tag_key: String!) {
              collectionDocumentTagDelete(id: $id, key: $tag_key) {
                __typename
                ... on CollectionDocument {
                  ...CollectionDocumentReference
                }
              }
            }

            fragment CollectionDocumentReference on CollectionDocument {
              id
              key
              data
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id, "tag_key": tag_key}
        response = await self.execute(
            query=query,
            operation_name="CollectionDocumentTagDelete",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionDocumentTagDelete.model_validate(data)

    async def collection_documents(
        self,
        collection_id: str,
        tag: Union[Optional[TagInput], UnsetType] = UNSET,
        after: Union[Optional[str], UnsetType] = UNSET,
        first: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> CollectionDocuments:
        query = gql(
            """
            query CollectionDocuments($collectionID: ID!, $tag: TagInput, $after: ID, $first: Int) {
              collection(id: $collectionID) {
                __typename
                ... on Collection {
                  id
                  key
                  documents(after: $after, first: $first, tag: $tag) {
                    edges {
                      node {
                        __typename
                        ... on CollectionDocument {
                          ...CollectionDocumentReference
                        }
                      }
                    }
                    pageInfo {
                      hasNextPage
                      endCursor
                    }
                  }
                }
              }
            }

            fragment CollectionDocumentReference on CollectionDocument {
              id
              key
              data
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "collectionID": collection_id,
            "tag": tag,
            "after": after,
            "first": first,
        }
        response = await self.execute(
            query=query,
            operation_name="CollectionDocuments",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionDocuments.model_validate(data)

    async def collection_file_create(
        self, collection_id: str, key: str, **kwargs: Any
    ) -> CollectionFileCreate:
        query = gql(
            """
            mutation CollectionFileCreate($collectionID: ID!, $key: ID!) {
              collectionFileCreate(collectionID: $collectionID, key: $key) {
                __typename
                ... on CollectionFile {
                  ...CollectionFileReference
                }
              }
            }

            fragment CollectionFileReference on CollectionFile {
              id
              key
              downloadURL
              uploadURL
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"collectionID": collection_id, "key": key}
        response = await self.execute(
            query=query,
            operation_name="CollectionFileCreate",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionFileCreate.model_validate(data)

    async def collection_file_delete(
        self, id: str, **kwargs: Any
    ) -> CollectionFileDelete:
        query = gql(
            """
            mutation CollectionFileDelete($id: ID!) {
              collectionFileDelete(id: $id) {
                __typename
                ... on CollectionFile {
                  ...CollectionFileReference
                }
                ... on CollectionFileNotFound {
                  ...CollectionFileNotFound
                }
              }
            }

            fragment CollectionFileNotFound on CollectionFileNotFound {
              id
            }

            fragment CollectionFileReference on CollectionFile {
              id
              key
              downloadURL
              uploadURL
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(
            query=query,
            operation_name="CollectionFileDelete",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionFileDelete.model_validate(data)

    async def collection_files(
        self,
        collection_id: str,
        tag: Union[Optional[TagInput], UnsetType] = UNSET,
        after: Union[Optional[str], UnsetType] = UNSET,
        first: Union[Optional[int], UnsetType] = UNSET,
        **kwargs: Any
    ) -> CollectionFiles:
        query = gql(
            """
            query CollectionFiles($collectionID: ID!, $tag: TagInput, $after: ID, $first: Int) {
              collection(id: $collectionID) {
                __typename
                ... on Collection {
                  id
                  key
                  files(after: $after, first: $first, tag: $tag) {
                    edges {
                      node {
                        __typename
                        ... on CollectionFile {
                          ...CollectionFileReference
                        }
                      }
                    }
                    pageInfo {
                      hasNextPage
                      endCursor
                    }
                  }
                }
              }
            }

            fragment CollectionFileReference on CollectionFile {
              id
              key
              downloadURL
              uploadURL
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {
            "collectionID": collection_id,
            "tag": tag,
            "after": after,
            "first": first,
        }
        response = await self.execute(
            query=query, operation_name="CollectionFiles", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CollectionFiles.model_validate(data)

    async def collection_file_tag_add(
        self, id: str, tag: TagInput, **kwargs: Any
    ) -> CollectionFileTagAdd:
        query = gql(
            """
            mutation CollectionFileTagAdd($id: ID!, $tag: TagInput!) {
              collectionFileTagAdd(id: $id, tag: $tag) {
                __typename
                ... on CollectionFile {
                  ...CollectionFileReference
                }
              }
            }

            fragment CollectionFileReference on CollectionFile {
              id
              key
              downloadURL
              uploadURL
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id, "tag": tag}
        response = await self.execute(
            query=query,
            operation_name="CollectionFileTagAdd",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionFileTagAdd.model_validate(data)

    async def collection_file_tag_delete(
        self, id: str, tag_key: str, **kwargs: Any
    ) -> CollectionFileTagDelete:
        query = gql(
            """
            mutation CollectionFileTagDelete($id: ID!, $tag_key: String!) {
              collectionFileTagDelete(id: $id, key: $tag_key) {
                __typename
                ... on CollectionFile {
                  ...CollectionFileReference
                }
              }
            }

            fragment CollectionFileReference on CollectionFile {
              id
              key
              downloadURL
              uploadURL
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id, "tag_key": tag_key}
        response = await self.execute(
            query=query,
            operation_name="CollectionFileTagDelete",
            variables=variables,
            **kwargs
        )
        data = self.get_data(response)
        return CollectionFileTagDelete.model_validate(data)

    async def collection_file(self, id: str, **kwargs: Any) -> CollectionFile:
        query = gql(
            """
            query CollectionFile($id: ID!) {
              collectionFile(id: $id) {
                __typename
                ... on CollectionFile {
                  ...CollectionFileReference
                }
              }
            }

            fragment CollectionFileReference on CollectionFile {
              id
              key
              downloadURL
              uploadURL
              tags {
                key
                value
              }
            }
            """
        )
        variables: Dict[str, object] = {"id": id}
        response = await self.execute(
            query=query, operation_name="CollectionFile", variables=variables, **kwargs
        )
        data = self.get_data(response)
        return CollectionFile.model_validate(data)
